@@ -20,7 +20,7 @@ package
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.08020';
+our $VERSION = '0.08320';
 
 require 5.006;
 
@@ -73,24 +73,70 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
     # use the defaults regardless of detected platform
 
 } elsif($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
+
+    my $arch;
     if(-x "/usr/bin/dpkg-architecture") {
-        my $arch = `/usr/bin/dpkg-architecture -qDEB_HOST_MULTIARCH`;
+        # works if dpkg-dev is installed
+        # rt96694
+        ($arch) = map { chomp; (split /=/)[1] }
+                  grep /^DEB_HOST_MULTIARCH=/,
+                  `/usr/bin/dpkg-architecture`;
+    } elsif(-x "/usr/bin/gcc") {
+        # works if gcc is installed
+        $arch = `/usr/bin/gcc -dumpmachine`;
         chomp $arch;
+    } else {
+        my $deb_arch = `dpkg --print-architecture`;
+        if($deb_arch =~ /^amd64/) {
+            if($^O eq 'linux') {
+                $arch = 'x86_64-linux-gnu';
+            } elsif($^O eq 'gnukfreebsd') {
+                $arch = 'x86_64-kfreebsd-gnu';
+            }
+        } elsif($deb_arch =~ /^i386/) {
+            if($^O eq 'linux') {
+                $arch = 'i386-linux-gnu';
+            } elsif($^O eq 'gnukfreebsd') {
+                $arch = 'i386-kfreebsd-gnu';
+            }
+        }
+    }
+
+    if($arch) {
+        if(scalar grep /--print-foreign-architectures/, `dpkg --help`)
+        {
+            # multi arch support / Debian 7+
+            @DEFAULT_SEARCH_PATH = (
+                "/usr/local/lib/$arch/pkgconfig",
+                "/usr/local/lib/pkgconfig",
+                "/usr/local/share/pkgconfig",
+                "/usr/lib/$arch/pkgconfig",
+                "/usr/lib/pkgconfig",
+                "/usr/share/pkgconfig",
+            );
+        } else {
+        
+            @DEFAULT_SEARCH_PATH = (
+                "/usr/local/lib/pkgconfig",
+                "/usr/local/lib/pkgconfig/$arch",
+                "/usr/local/share/pkgconfig",
+                "/usr/lib/pkgconfig",
+                "/usr/lib/pkgconfig/$arch",
+                "/usr/share/pkgconfig",
+            );
+        }
+    
+    } else {
+
         @DEFAULT_SEARCH_PATH = (
-            "/usr/local/lib/$arch/pkgconfig",
             "/usr/local/lib/pkgconfig",
             "/usr/local/share/pkgconfig",
-            "/usr/lib/$arch/pkgconfig",
             "/usr/lib/pkgconfig",
             "/usr/share/pkgconfig",
         );
-    } else {
-        # TODO: the debian 6 official pkg-config also includes
-        # /usr/local/lib/pkgconfig/x86_64-linux-gnu
-        # /usr/lib/pkgconfig/x86_64-linux-gnu    
-        # but not sure if they are used
-    }
 
+    }
+    
 } elsif($^O eq 'linux' && -r "/etc/redhat-release") {
 
     if(-d "/usr/lib64/pkgconfig") {
@@ -330,6 +376,10 @@ struct(
      'print_variable' => '$',
      'print_values' => '$',
      'defined_variables' => '*%',
+     
+     # for creating PkgConfig objects with identical
+     # settings
+     'original' => '$',
     ]
 );
 
@@ -409,6 +459,8 @@ sub find {
         ['exclude_cflags', \@DEFAULT_EXCLUDE_CFLAGS]
     );
     
+    my %original = %options;
+    
     foreach (@uspecs) {
         my ($basekey,$default) = @$_;
         my $list = [ @{$options{$basekey} ||= [] } ];
@@ -425,6 +477,7 @@ sub find {
     $VarClassSerial++;
     $options{varclass} = sprintf("PkgConfig::Vars::SERIAL_%d", $VarClassSerial);
     $options{udefclass} = sprintf("PkgConfig::UDefs::SERIAL_%d", $VarClassSerial);
+    $options{original} = \%original;
     
     
     my $udefs = delete $options{VARS} || {};
@@ -666,11 +719,18 @@ sub parse_pcfile {
         $self->pkg_description( $self->_pc_var('description') );
         $self->pkg_exists(1);        
     }
-    
+
     unless ($self->no_recurse) {
         foreach (@deps) {
             my ($dep,$cmp_op,$version) = @$_;
-            $self->find_pcfile($dep);
+            $dep = "$dep $cmp_op $version" if defined $cmp_op;
+            my $other = PkgConfig->find($dep, %{ $self->original });
+            if($other->errmsg) {
+                $self->errmsg($other->errmsg);
+                last;
+            }
+            $self->append_cflags(  $other->get_cflags );
+            $self->append_ldflags( $other->get_ldflags );
         }
     }
 }
@@ -1476,6 +1536,8 @@ Other contributors include:
 
 =over 4
 
+=item Vladimir Timofeev (vovkasm)
+
 =item kmx
 
 =item Sanel Zukan
